========================================================================================
PyMVPA -- Updated Multivariate Pattern Analysis in Python |build-status| |coverage-status| |doi|
========================================================================================

.. |doi|
   image:: https://img.shields.io/badge/doi-10.3389%2Fneuro.11.003.2009-green.svg
   :target: http://dx.doi.org/10.3389/neuro.11.003.2009
   :alt: Original PyMVPA publication

.. |build-status|
   image:: https://secure.travis-ci.org/PyMVPA/PyMVPA.png
           ?branch=master
   :target: http://travis-ci.org/PyMVPA/PyMVPA
   :alt: PyMVPA travis-ci build status

.. |coverage-status|
   image:: https://coveralls.io/repos/PyMVPA/PyMVPA/badge.png
           ?branch=master
   :target: https://coveralls.io/r/PyMVPA/PyMVPA
   :alt: PyMVPA coveralls coverage status

PyMVPA is a Python package intended to ease statistical learning analyses of
large datasets. It offers an extensible framework with a high-level interface
to a broad range of algorithms for classification, regression, feature selection,
data import and export. It is designed to integrate well with related software packages,
such as scikit-learn, shogun, MDP, etc.

While it is not limited to the neuroimaging domain,
it is eminently suited for such datasets.
PyMVPA is free software and requires nothing but free-software to run.

PyMVPA stands for MultiVariate Pattern Analysis (MVPA) in Python.

PyMVPA is now also available on the Python Package Index (PyPI)
and can be easily installed using `pip`:
    ```bash
    pip install PyMVPA
    ```

    This command will download and install the latest version of PyMVPA and its required dependencies.
